summaryrefslogtreecommitdiffstats
path: root/Lib/StringIO.py
diff options
context:
space:
mode:
authorMarc-André Lemburg <mal@egenix.com>2002-01-06 17:15:05 (GMT)
committerMarc-André Lemburg <mal@egenix.com>2002-01-06 17:15:05 (GMT)
commitf853be980ee54e8f61fa8d70a7b4724e26ac2035 (patch)
treedd0f3960724eb8991eff5fd5c9afb1a1ae6d93c2 /Lib/StringIO.py
parent23105d5c24579ae0278ed4dcd3905565e15f34a3 (diff)
downloadcpython-f853be980ee54e8f61fa8d70a7b4724e26ac2035.zip
cpython-f853be980ee54e8f61fa8d70a7b4724e26ac2035.tar.gz
cpython-f853be980ee54e8f61fa8d70a7b4724e26ac2035.tar.bz2
Restore Python 2.1 StringIO.py behaviour: support concatenating
Unicode string snippets to larger Unicode strings. This fix should also go into Python 2.2.1.
Diffstat (limited to 'Lib/StringIO.py')
-rw-r--r--Lib/StringIO.py13
1 files changed, 8 insertions, 5 deletions
diff --git a/Lib/StringIO.py b/Lib/StringIO.py
index e7c8e04..1840bad 100644
--- a/Lib/StringIO.py
+++ b/Lib/StringIO.py
@@ -28,7 +28,7 @@ Notes:
bytes that occupy space in the buffer.
- There's a simple test set (see end of this file).
"""
-
+import types
try:
from errno import EINVAL
except ImportError:
@@ -38,8 +38,10 @@ __all__ = ["StringIO"]
class StringIO:
def __init__(self, buf = ''):
- # Force self.buf to be a string
- self.buf = str(buf)
+ # Force self.buf to be a string or unicode
+ if type(buf) is not types.UnicodeType:
+ buf = str(buf)
+ self.buf = buf
self.len = len(buf)
self.buflist = []
self.pos = 0
@@ -135,8 +137,9 @@ class StringIO:
if self.closed:
raise ValueError, "I/O operation on closed file"
if not s: return
- # Force s to be a string
- s = str(s)
+ # Force s to be a string or unicode
+ if type(s) is not types.UnicodeType:
+ s = str(s)
if self.pos > self.len:
self.buflist.append('\0'*(self.pos - self.len))
self.len = self.pos